@@ -167,9 +167,9 @@ var emptyEnumeration = new java.util.Enumeration() {
 function wrapRoot(root) {
     if (root) {
         return {
-            id: root.instance.getInstanceId(),
+            get id() { return i = root.instance; return (i) ? i.getInstanceId() : 0; },
             description: "Reference " + root.kind,
-            referrer: wrapJavaValue(root.instance),
+            get referrer() { return wrapJavaValue(root.instance); },
             type: root.kind,
             wrapped: root
         };
@@ -439,8 +439,8 @@ function JavaClassWrapper(jclass) {
     }
 
     this.loader = wrapJavaObject(jclass.classLoader);
-    this.signers = undefined; //TODO wrapJavaValue(jclass.getSigners());
-    this.protectionDomain = undefined; //TODO wrapJavaValue(jclass.getProtectionDomain());
+    this.signers = wrapJavaValue(jclass.getSigners());
+    this.protectionDomain = wrapJavaValue(jclass.getProtectionDomain());
     Object.defineProperty(this, "fields", {
         get:function() { return wrapIterator(jclass.fields.iterator(), true); }
     });
